@@ -2,13 +2,13 @@ package MD5Check;
 
 use strict;
 use warnings;
-use utf8;
 use Digest::MD5;
 require Exporter;
 
 our @ISA    = qw(Exporter);
 our @EXPORT = qw(init md5init md5check);
 
+=encoding utf8
 =head1 NAME
 
 MD5Check -  Use it for init Web files's md5 values of your site(or other dir), and check if it changed!
@@ -17,11 +17,11 @@ MD5Check -  Use it for init Web files's md5 values of your site(or other dir), a
 
 =head1 VERSION
 
-Version 0.09
+Version 0.11
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.11';
 
 =head1 SYNOPSIS
 
@@ -56,8 +56,7 @@ sub md5_sum {
 
     my ( $file_name, $mode ) = @_;
     my ( $FD, $ctx, $md5 );
-    eval {open( $FD, $file_name ) or warn  "Can't open $file_name !";
-     };
+    eval {open( $FD, $file_name ) or warn  "Can't open $file_name !";};
    unless($@) { 
     $ctx = Digest::MD5->new;
     binmode($FD) if $mode;
@@ -73,9 +72,13 @@ sub md5check {
     open( my $fd, '<', $file ) or warn "$file: $!\n";
     my $res .= $file . "\n";
     while (<$fd>) {
+        chomp;
         next if /$file/; # ignore the recode file itself
-        my ( $name, $sum ) = split /\s+/;
-        $name =~ s/^\*//;
+        my ( $name, $sum ) = split /\|\|/;
+        print $name,"\n" if $DEBUG;
+        print $sum,"\n" if $DEBUG;
+        print md5_sum( $name, 1 ),"\n" if $DEBUG;
+        $name =~ s/^\#//;
         if ( $sum eq md5_sum( $name, 1 ) ) {
             $res .= "$name OK\n";
         }
@@ -100,18 +103,18 @@ sub init {
 
             #print "按照文本模式进行计算MD5!\n";
            my $md5value = md5_sum( $fd, 0 );
-            print "$fd\t$md5value\n" ;
+            print "$fd||$md5value\n" ;
         }
         elsif ( -B $fd ) {
 
             #print "二进制文件用binmod计算MD5!\n";
             my $md5value = md5_sum( $fd, 1 );
-            print  "$fd\t$md5value\n";
+            print  "$fd||$md5value\n";
         }
         else {
             #print "其他文件，按照bimmod计算!\n";
             my $md5value = md5_sum( $fd, 1 );
-           print  "$fd\t$md5value\n";
+           print  "$fd||$md5value\n";
         }
     }
     elsif ( -d $fd ) {
@@ -139,18 +142,18 @@ sub md5init {
 
             #print "按照文本模式进行计算MD5!\n";
            my $md5value = md5_sum( $fd, 0 );
-            print $outFD  "$fd\t$md5value\n" ;
+            print $outFD  "$fd||$md5value\n" ;
         }
         elsif ( -B $fd ) {
 
             #print "二进制文件用binmod计算MD5!\n";
             my $md5value = md5_sum( $fd, 1 );
-            print $outFD "$fd\t$md5value\n";
+            print $outFD "$fd||$md5value\n";
         }
         else {
             #print "其他文件，按照bimmod计算!\n";
             my $md5value = md5_sum( $fd, 1 );
-           print $outFD  "$fd\t$md5value\n";
+           print $outFD  "$fd||$md5value\n";
         }
     }
     elsif ( -d $fd ) {
